package Cobol::Compiler::ProgramToken;

use parent 'Token';

use constant PROCEDURETOKENS => qw(PROCEDURE);

sub new {
	my ($class, $name) = @_;
        my $self = $class->SUPER::new;

	$self->{subTokens}[Cobol::Compiler::ProgramToken->PROCEDURE] = 101;

}

